@@ -1,5 +1,5 @@
 from django.contrib import admin
-from tax_toffee import models as mod
+from taxbot import models as mod
 
 # Register your models here.
 admin.site.register(mod.Tax)
